@@ -1,4 +1,4 @@
-# Copyright 2019 John Reese
+# Copyright 2020 John Reese
 # Licensed under the MIT license
 
 """
@@ -6,7 +6,7 @@ asyncio db query generator
 """
 
 __author__ = "John Reese"
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 from .column import Column
 from .connector import connect
@@ -14,4 +14,4 @@ from .engines.base import Connection, Cursor, Engine, Result
 from .errors import AqlError, QueryError
 from .query import Query
 from .table import Table, table
-from .types import And, Boolean, Comparison, Join, Operator, Or, Select
+from .types import And, Boolean, Comparison, Join, Location, Operator, Or, Select
